@@ -9,16 +9,16 @@ pub struct SwapDetailsResponse {
     pub receiver: String,
     pub swap_address: String,
     pub token1_amount: Uint128,
-    pub code_id: u64
+    pub type_code: String
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum QueryMsg {
     Token1ForToken2Price {
-        code_id: u64
+        type_code: String
     },
     SwapDetails {
-        code_id: u64
+        type_code: String
     }
 }
